# User guide

This user guide provides examples of using Awkward Array, organised by high-level topic into subsections. Each subsection provides an introduction to the topic, and is split into smaller pages that focus on a particular set of features.  

New users should start with {doc}`10-minutes-to-awkward-array`.

```{tableofcontents}
```
